@@ -3,8 +3,11 @@
 package Devel::AssertOS::Realtime;
 
 use Devel::CheckOS;
+use strict;
+use warnings;
+no warnings 'redefine';
 
-$VERSION = '1.2';
+our $VERSION = '1.2';
 
 sub matches { return qw(QNX); }
 sub os_is { Devel::CheckOS::os_is(matches()); }
